@@ -38,6 +38,7 @@ class download:
 
     def download(self):
         show_name = self._get_valid_pathname(self.entry.show_name)
+        show_name.strip()
         self.show_folder = Config().download_folder_path / f"{show_name}"
 
         if Config().download_remove_dub_from_folder_name:
@@ -63,7 +64,7 @@ class download:
             print(
                 f"{colors.GREEN}Skipping Already Existing:{colors.RED} {self.entry.show_name} EP: {self.entry.ep} - {self.entry.quality} {colors.END}"
             )
-            return
+            return dl_path
 
         print("-" * 20)
         print(
@@ -75,7 +76,7 @@ class download:
             if self.ffmpeg or Config().ffmpeg_hls:
                 print(f"{colors.CYAN}Downloader:{colors.RED} ffmpeg")
                 self.ffmpeg_dl()
-                return
+                return dl_path
 
             print(f"{colors.CYAN}Downloader:{colors.RED} internal")
             self.multithread_m3u8_dl()
@@ -83,6 +84,8 @@ class download:
             print(f"{colors.CYAN}Type:{colors.RED} mp4")
             self.mp4_dl(self.entry.stream_url)
 
+        return dl_path
+
     def ffmpeg_dl(self):
         Config().user_files_path.mkdir(exist_ok=True, parents=True)
         Config().ffmpeg_log_path.mkdir(exist_ok=True, parents=True)
